@@ -7,52 +7,12 @@ diag.plot <- function(x,plots, subset, ...)
       weights   <- cbind(unw=rep(1,nrow(weights)),weights)
       propScores <- cbind(unw=rep(0.5,nrow(propScores)),propScores)
    }
-   
-   dots <- list(...)
-   
-   n.tp <- ifelse(class(x) == "dxwts", length(x$desc), ncol(weights))
-   hldEffSz <- NULL
-   tpHld <- NULL
-   hldPVal <- hldksPVal <- hldksPValRanks <- hldTVal <- hldTRank <- hldESBig <- NULL
-   desc.unw <- x$desc[[1]]
-   for (i in 2:n.tp){
-   	desc.temp <- x$desc[[i]]
-   	iter <- desc.temp$n.trees
-   	tpHld <- c(tpHld, names(x$desc[i]))
-   	
-   	hldEffSz <- c(hldEffSz, desc.temp$bal.tab$results$std.eff.sz, desc.unw$bal.tab$results$std.eff.sz)
-   	hldPVal <- c(hldPVal, desc.temp$bal.tab$results$p, desc.unw$bal.tab$results$p)
-    hldksPVal <- c(hldksPVal, desc.temp$bal.tab$results$ks.pval, desc.unw$bal.tab$results$ks.pval)
-    hldksPValRanks <- c(hldksPValRanks, rank(desc.temp$bal.tab$results$ks.pval, ties.method = "first"), rank(desc.unw$bal.tab$results$ks.pval, ties.method = "first"))
-    hldTVal <- c(hldTVal, desc.temp$bal.tab$results$p, desc.unw$bal.tab$results$p)
-    hldTRank <- c(hldTRank, rank(desc.temp$bal.tab$results$p, ties.method = "first"), rank(desc.unw$bal.tab$results$p, ties.method = "first"))
-    hldESBig <- c(hldESBig, rep(abs(desc.temp$bal.tab$results$std.eff.sz) > abs(desc.unw$bal.tab$results$std.eff.sz),2))
-
-   	
-   }
-   
-   n.var <- length(hldEffSz)/(2*(n.tp - 1))
-   
-   	## form data.frame w/: p-val, es, weight/not, whichVar,
-   	esDat <- data.frame(effectSize = abs(hldEffSz), 
-   	pVal=0+1*(hldPVal > 0.05), 
-   	whichComp = as.factor(rep(tpHld, each = 2*n.var)), 
-   	weighted = as.factor(rep(rep(c("Weighted", "Unweighted"), each = n.var), (n.tp-1))), 
-   	whichVar = factor(rep(1:n.var, 2*(n.tp-1))), 
-   	ksPVal = hldksPVal, 
-   	ksRank = hldksPValRanks, 
-   	tPVal = hldTVal,
-   	tRank = hldTRank,
-   	esBig = hldESBig)   
-   	
-#   	return(esDat)
-
-
-#sbSt <- esDat$stopRule %in% levels(esDat$stopRule)[1:length(levels(esDat$stopRule))]
+    
+whichVar <- pVal <- weighted <- varb <- NULL   
 
 if (plots == "optimize" || plots == 1) {
-	longBal <- matrix(t(x$balance))
-	optDat <- data.frame(balance = longBal, iteration = rep(x$iters, each = n.tp-1), stopRule = names(x$desc)[-1])
+	
+	optDat <- makePlotDat(x, whichPlot = 1)
 
 	if(is.null(subset))
 	subset <- 1:length(levels(as.factor(optDat$stopRule)))
@@ -64,51 +24,63 @@ if (plots == "optimize" || plots == 1) {
    
    if (plots == "es" || plots == 3)	{ ## es plot
    	
+   	esDat <- makePlotDat(x, whichPlot = 3, yOnly = FALSE)
+   	
    	if(is.null(subset))
    	subset <- 1:length(levels(as.factor(esDat$whichComp)))
    	
-   	yMax <- min(3,max(esDat[,1], na.rm=TRUE),na.rm=TRUE) + .05	
+   	yMax <- min(3,max(esDat$effectSize)) + .05	
    	
-   	if(max(esDat[,1], na.rm=TRUE) > 3)
+   	nullPlot <- TRUE
+   	
+   	if(max(esDat[,1]) > 3)
    	warning("Some effect sizes are larger than 3 and may not have been plotted.\n")	
    	
-   	pt1 <- xyplot(effectSize ~ weighted | whichComp, groups = whichVar, data = esDat, scales = list(alternating = 1),
+   	subsetHold <- !esDat$esBig & (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset])
+   	
+   	if(any(subsetHold)){
+   	pt1.1 <- xyplot(effectSize ~ weighted | whichComp, groups = whichVar, data = esDat, scales = list(alternating = 1),
    	ylim = c(-.05, yMax), type = "l", col = "lightblue", 
-   	subset = !esBig & (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]), 
+   	subset = subsetHold, 
    	ylab = "Absolute standard difference", xlab = NULL, ...,
    	panel = function(...){
    		panel.abline(h=c(.2,.5,.8), col="gray80")
    		panel.xyplot(...)
    		
    	})
+   	ptHold <- pt1.1
+   	nullPlot <- FALSE
+   	}
    	
-   	if(sum((esDat$esBig & (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset])) == TRUE, na.rm=TRUE)>0){
+   	subsetHold <- esDat$esBig & (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset])
    	
+   	if(any(subsetHold)){
    	pt1.2 <- xyplot(effectSize ~ weighted | whichComp, groups = whichVar, 
    	data = esDat, ylab = "Absolute standard difference", xlab = NULL,
    	ylim = c(-.05, yMax), type = "l", col = "red", 
-   	subset = esBig & (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]), lwd = 2)
-   	
-   	pt1 <- pt1 + pt1.2
-   	
+   	subset = subsetHold, lwd = 2)
+   	if(nullPlot){
+   		ptHold <- pt1.2
+   		nullPlot <- FALSE
+   	}
+   	else ptHold <- ptHold + pt1.2
    	}
    	
+   	subsetHold <- as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]
    	
-   	if(sum(as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset] == TRUE, na.rm = TRUE)>0){
+   	if(all(esDat$pVal < 0.05)) pchHold <- 19
+   	else if(all(esDat$pVal >= 0.05)) pchHold <- 1
+   	else pchHold <- c(19,1)
    	
+   	if(any(subsetHold)){
    	pt2 <- xyplot(effectSize ~ weighted | whichComp, groups = pVal, data = esDat,
    	ylab = "Absolute standard difference", xlab = NULL, 
-   	ylim = c(-.05, yMax), type = "p", col = "red", pch = c(19,1),
-   	subset = as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset])
-   	
-   	pt1 <- pt1 + pt2
-   	
+   	ylim = c(-.05, yMax), type = "p", col = "red", pch = pchHold,
+   	subset = subsetHold)
+   	ptHold <- ptHold + pt2
    	}
    	
-#   	else pt2 <- NULL
-   	
-#   	pt1 <- pt1.1 + pt1.2 + pt2
-  
+   	pt1 <- ptHold
    	
    	}
    						
@@ -116,13 +88,15 @@ if (plots == "optimize" || plots == 1) {
    
    if (plots == "t" || plots == 4) { ## t p-values plot
    	
-   	   	if(is.null(subset))
-   	subset <- 1:length(levels(as.factor(esDat$whichComp)))
+   	esDat <- makePlotDat(x, whichPlot = 4)
+   	if(is.null(subset)) subset <- 1:length(levels(as.factor(esDat$whichComp)))
+   	
+   	
    	
    	n.var2 <- max(esDat$tRank * (!is.na(esDat$tPVal)), na.rm=TRUE)
    	
    	pt1 <- xyplot(tPVal~tRank|whichComp, groups = weighted, data=esDat, xlab = "Rank of p-value rank for pretreatment variables \n (hollow is weighted, solid is unweighted)", ylab = "T test p-values", pch = c(19,1), col = "black", scales = list(alternating = 1),
-   	subset = (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]) & (esDat$tRank <= n.var2), ..., 
+   	subset = (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]) & (esDat$tRank <= n.var2), ylim = c(-.1, 1.1), ..., 
    	   	panel = function(...){
    	   		panel.xyplot(x=c(1,n.var2), y=c(0,1), col="lightblue", type="l")
 #   		panel.abline(a=0, b=1, col="lightblue")
@@ -133,13 +107,14 @@ if (plots == "optimize" || plots == 1) {
    	}
    
    if (plots =="ks" || plots ==5) {  ## ks plot
+   	esDat <- makePlotDat(x, whichPlot = 5)
    	
    	if(is.null(subset))
    	subset <- 1:length(levels(as.factor(esDat$whichComp)))
    	
    	n.var2 <- max(esDat$ksRank*(!is.na(esDat$ksPVal)), na.rm=TRUE)
    	
-   	pt1 <- xyplot(ksPVal~ksRank|whichComp, groups=weighted, scales = list(alternating = 1), data = esDat, ..., xlab = "Rank of p-value rank for pretreatment variables \n (hollow is weighted, solid is unweighted)", ylab = "KS test p-values", pch = c(19,1), col="black",
+   	pt1 <- xyplot(ksPVal~ksRank|whichComp, groups=weighted, scales = list(alternating = 1), data = esDat,ylim = c(-.1, 1.1), ..., xlab = "Rank of p-value rank for pretreatment variables \n (hollow is weighted, solid is unweighted)", ylab = "KS test p-values", pch = c(19,1), col="black",
    	subset = (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]) & (esDat$ksRank <= n.var2),
    	panel = function(...){
    		panel.xyplot(x=c(1,n.var2), y=c(0,1), col="lightblue", type="l")
